"""Speech-to-text transcription tools."""

import logging
from typing import Optional

from voice_mcp.server_new import mcp

logger = logging.getLogger("voice-mcp")

# Placeholder - transcription tools will be implemented here
# This would include tools for:
# - Direct STT transcription
# - File-based transcription
# - Real-time transcription